Package: DeconvoBuddies
Title: Helper Functions for LIBD Deconvolution
Version: 1.4.0
Date: 2026-04-15
Authors@R: 
    c(
    person(given = "Louise", family = "Huuki-Myers", role = c("aut", "cre"),
    email = "lahuuki@gmail.com", comment = c(ORCID = "0000-0001-5148-3602")),
    person("Leonardo", "Collado-Torres", role = c("ctb"), 
    email = "lcolladotor@gmail.com", comment = c(ORCID = "0000-0003-2140-308X")),
    person("Nicholas J.", "Eagles", email = "nickeagles77@gmail.com",
    role = c("ctb"), comment = c(ORCID = "0000-0002-9808-5254"))
    )
Description: Functions helpful for LIBD deconvolution project. Includes
        tools for marker finding with mean ratio, expression plotting,
        and plotting deconvolution results. Working to include DLPFC
        datasets.
License: Artistic-2.0
URL: https://github.com/LieberInstitute/DeconvoBuddies
BugReports: https://github.com/LieberInstitute/DeconvoBuddies/issues
biocViews: Software, SingleCell, RNASeq, GeneExpression,
        Transcriptomics, ExperimentHubSoftware
Encoding: UTF-8
Roxygen: list(markdown = TRUE)
RoxygenNote: 7.3.3
Imports: AnnotationHub, BiocFileCache, BiocParallel,
        DelayedMatrixStats, dplyr, ExperimentHub, ggplot2, ggrepel,
        graphics, grDevices, MatrixGenerics, methods, purrr, rafalib,
        reshape2, S4Vectors, scran, SingleCellExperiment, spatialLIBD,
        stats, stringr, SummarizedExperiment, tibble, utils
Suggests: Biobase, BiocStyle, covr, HDF5Array, knitr, RColorBrewer,
        RefManageR, rmarkdown, sessioninfo, testthat (>= 3.0.0), tidyr,
        tidyverse
Config/testthat/edition: 3
Depends: R (>= 4.4.0)
VignetteBuilder: knitr
Config/pak/sysreqs: libcairo2-dev cmake libfontconfig1-dev
        libfreetype6-dev libfribidi-dev libglpk-dev make
        libharfbuzz-dev libmagick++-dev gsfonts libbz2-dev libicu-dev
        libjpeg-dev liblzma-dev libpng-dev libtiff-dev libuv1-dev
        libwebp-dev libxml2-dev libssl-dev perl xz-utils zlib1g-dev
Repository: https://bioc-release.r-universe.dev
Date/Publication: 2026-04-28 13:04:46 UTC
RemoteUrl: https://github.com/bioc/DeconvoBuddies
RemoteRef: RELEASE_3_23
RemoteSha: f117cdae8abcf7d489b9a8fb383256e5a9dc9e6b
NeedsCompilation: no
Packaged: 2026-04-29 21:06:32 UTC; root
Author: Louise Huuki-Myers [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-5148-3602>),
  Leonardo Collado-Torres [ctb] (ORCID:
    <https://orcid.org/0000-0003-2140-308X>),
  Nicholas J. Eagles [ctb] (ORCID:
    <https://orcid.org/0000-0002-9808-5254>)
Maintainer: Louise Huuki-Myers <lahuuki@gmail.com>
Built: R 4.6.0; ; 2026-04-29 21:59:53 UTC; unix
