# Generated by roxygen2: do not edit by hand

export(create_cell_colors)
export(fetch_deconvo_data)
export(findMarkers_1vAll)
export(get_mean_ratio)
export(make_test_sce)
export(plot_composition_bar)
export(plot_gene_express)
export(plot_marker_express)
export(plot_marker_express_ALL)
export(plot_marker_express_List)
import(BiocFileCache)
import(ExperimentHub)
import(dplyr)
importFrom(AnnotationHub,query)
importFrom(BiocParallel,SerialParam)
importFrom(BiocParallel,bplapply)
importFrom(DelayedMatrixStats,rowMedians)
importFrom(MatrixGenerics,rowMeans)
importFrom(MatrixGenerics,rowMedians)
importFrom(S4Vectors,DataFrame)
importFrom(SingleCellExperiment,SingleCellExperiment)
importFrom(SummarizedExperiment,colData)
importFrom(dplyr,arrange)
importFrom(dplyr,group_by)
importFrom(dplyr,mutate)
importFrom(dplyr,rename)
importFrom(dplyr,summarise)
importFrom(ggplot2,aes)
importFrom(ggplot2,element_text)
importFrom(ggplot2,facet_wrap)
importFrom(ggplot2,geom_bar)
importFrom(ggplot2,geom_text)
importFrom(ggplot2,geom_violin)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,stat_summary)
importFrom(ggplot2,theme)
importFrom(grDevices,colorRampPalette)
importFrom(grDevices,hcl)
importFrom(graphics,barplot)
importFrom(graphics,par)
importFrom(graphics,text)
importFrom(methods,is)
importFrom(purrr,map)
importFrom(purrr,map2)
importFrom(rafalib,splitit)
importFrom(scran,findMarkers)
importFrom(spatialLIBD,fetch_data)
importFrom(stats,rpois)
importFrom(stringr,str_pad)
importFrom(tibble,add_column)
importFrom(tibble,as_tibble)
importFrom(tibble,rownames_to_column)
importFrom(tibble,tibble)
importFrom(utils,head)
